@@ -29,7 +29,6 @@ import traceback
 import cfg
 import lessonfile
 import osutils
-import const
 
 class QstatusDefs:
     QSTATUS_NO = 0
@@ -66,11 +65,6 @@ class Teacher(cfg.ConfigUtils, QstatusDefs):
             self.m_timeout_handle = None
         self.q_status = self.QSTATUS_NO
         soundcard.synth.stop()
-        # We test for m_P because m_P might be None in some cases. For example
-        # if the user answers no when asked to run a lesson file that will 
-        # run external programs.
-        if self.m_statistics and self.m_P:
-            self.m_statistics.save_data()
     def exit_test_mode(self):
         """
         Shared between harmonic and melodic interval.
@@ -84,7 +78,7 @@ class Teacher(cfg.ConfigUtils, QstatusDefs):
         self.m_lessonfile = lessonfile
         self.parse_lessonfile()
         if self.m_P and self.m_statistics:
-            self.m_statistics.lessonfile_changed(self.m_lessonfile)
+            self.m_statistics.lessonfile_changed()
     def parse_lessonfile(self):
         self.m_question = None
         self.q_status = self.QSTATUS_NO
@@ -225,6 +219,24 @@ class MelodicIntervalTeacher(Teacher):
 
 
 class RhythmAddOnClass:
+    RHYTHMS = ("c4", "c8 c8", "c16 c16 c16 c16", "c8 c16 c16",
+               "c16 c16 c8", "c16 c8 c16", "c8. c16", "c16 c8.",
+               "r4", "r8c8", "r8 c16 c16", "r16 c16 c8", "r16c8c16",
+               "r16 c16 c16 c16", "r8 r16 c16", "r16 c8.",
+               "c12 c12 c12", "r12 c12 c12",
+               "c12 r12 c12", "c12 c12 r12", "r12 r12 c12", "r12 c12 r12",
+               "c4.", "c4 c8", # 22, 23
+               "c8 c4", "c8 c8 c8", # 24, 25
+               "c4 c16 c16", # 26
+               "c16 c16 c4", # 27
+               "c8 c8 c16 c16", #28
+               "c8 c16 c16 c8", #29
+               "c16 c16 c8 c8", #30
+               "c8 c16 c16 c16 c16", #31
+               "c16 c16 c8 c16 c16", #32
+               "c16 c16 c16 c16 c8", #33
+               "c16 c16 c16 c16 c16 c16", #34
+               )
     def new_question(self):
         """returns:
                self.ERR_PICKY : if the question is not yet solved and the
@@ -246,7 +258,7 @@ class RhythmAddOnClass:
         norest_v = []
         v = []
         for x in self.m_P.header.rhythm_elements:
-            if not (const.RHYTHMS[x][0] == "r"
+            if not (self.RHYTHMS[x][0] == "r"
                     and self.get_bool("not_start_with_rest")):
                 norest_v.append(x)
             v.append(x)
@@ -271,7 +283,7 @@ class RhythmAddOnClass:
             else:
                 count_in_notelen = "4"
             s = "d%s " % count_in_notelen * self.get_int("count_in")
-        s += " ".join([const.RHYTHMS[k] for k in self.m_question])
+        s += " ".join([self.RHYTHMS[k] for k in self.m_question])
         return s
     def get_music_string(self):
         """
@@ -372,10 +384,9 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
     def do_test_complete(self):
         self.on_end_practise()
         req = self.m_t.m_P.get_test_requirement()
-        res = self.m_t.m_statistics.get()
+        res = self.m_t.m_statistics.get_last_test_result()
         if res >= req:
             gu.dialog_ok(_("Test completed!\nYour score was %(score).1f%%.\nThe test requirement was %(requirement).1f%%.") % {'score': res * 100, 'requirement': req * 100})
-            self.m_t.m_statistics.store_test_passed()
         else:
             gu.dialog_ok(_("Test failed.\nYour score was %(score).1f%%.\nThe test requirement was %(requirement).1f%%.") % {'score': res * 100, 'requirement': req * 100})
         self.g_cancel_test.hide()
@@ -561,7 +572,7 @@ class RhythmAddOnGuiClass(object):
         table.show_all()
     def pngcheckbutton(self, i):
         btn = gtk.CheckButton()
-        btn.add(gu.create_rhythm_image(const.RHYTHMS[i]))
+        btn.add(gu.create_rhythm_image(RhythmAddOnClass.RHYTHMS[i]))
         btn.show()
         btn.connect('clicked', self.select_element_cb, i)
         return btn
