@@ -161,8 +161,7 @@ class Gui(abstract.LessonbasedGui):
                 self.g_guess_answer.set_sensitive(False)
                 self.g_give_up.set_sensitive(False)
                 self.g_backspace.set_sensitive(False)
-                if self.m_t.m_P.header.have_music_displayer:
-                    self.run_exception_handled(self.show_answer)
+                self.show_answer()
             else:
                 self.g_flashbar.flash(_("Wrong"))
                 max_button_height = 0
@@ -202,8 +201,7 @@ class Gui(abstract.LessonbasedGui):
             b = MultiButton(elem['label'])
             b.show()
             self.g_answer.pack_start(b, False, False)
-        if self.m_t.m_P.header.have_music_displayer:
-            self.run_exception_handled(self.show_answer)
+        self.show_answer()
         self.g_new.set_sensitive(True)
         self.g_give_up.set_sensitive(False)
         self.g_guess_answer.set_sensitive(False)
@@ -233,6 +231,8 @@ class Gui(abstract.LessonbasedGui):
         else:
             self.g_music_displayer.hide()
         #
+        if not self.m_t.m_custom_mode:
+            self.m_t.m_statistics.reset_session()
         self.g_statview.g_heading.set_text(self.m_t.m_P.header.title)
         self.m_elem_button_max_height = 0
         for elem in self.m_t.m_P.header.elements:
