@@ -261,7 +261,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
             self.g_new_tone.grab_focus()
             self.g_give_up.set_sensitive(False)
     def set_percentage_label(self):
-        self.g_percentage.set_text("%.1f %%" % (self.m_t.m_statistics.get()*100))
+        self.g_percentage.set_text("%.1f %%" % (self.m_t.m_statistics.get_percentage_correct()))
     def on_start_practise(self):
         if not self.m_usable:
             return
