@@ -15,22 +15,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import logging
-import logging.handlers
-import optionparser
-
-opt_parser = optionparser.SolfegeOptionParser()
-options, args = opt_parser.parse_args()
-
-if options.debug:
-    handler = logging.StreamHandler()
-    logging.getLogger().addHandler(handler)
-    logging.getLogger().setLevel(logging.DEBUG)
-else:
-    handler = logging.handlers.MemoryHandler(1)
-    logging.getLogger().addHandler(handler)
-
-
 import webbrowser
 import textwrap
 # We move x-www-browser to the end of the list because on my
@@ -74,6 +58,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 import osutils
+import app
+
+opt_parser = app.SolfegeOptionParser()
+options, args = opt_parser.parse_args()
 
 if options.version:
     if buildinfo.is_release():
@@ -147,7 +135,6 @@ import tracebackwindow
 
 sys.stderr = tracebackwindow.TracebackWindow(options.show_gtk_warnings)
 
-import app
 from configwindow import ConfigWindow
 import mpd
 import mpd.musicdisplayer
@@ -186,6 +173,7 @@ from trainingsetdlg import TrainingSetDialog
 from practisesheetdlg import PractiseSheetDialog
 from helpbrowser import HelpBrowser, DocViewer
 import filesystem
+import statistics
 
 class MusicViewerWindow(gtk.Dialog):
     def __init__(self, app):
@@ -420,7 +408,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
                         "%s%i" % (lesson_id, id_counter),
                         None, menutitle, None, None,
                         lambda o, e=lesson_id: self.m_app.practise_lesson_id(e)))
-                    if self.m_app.lessonfile_manager.is_test_passed(lesson_id):
+                    if statistics.db.is_test_passed(lesson_id):
                         menutitle = _("%s (passed)") % menutitle
                     if self.m_app.lessonfile_manager.get(lesson_id, 'test'):
                         actions.append((
@@ -671,7 +659,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             os.path.exists(os.path.join(filesystem.app_data(),
                                         "learningtrees"))):
             if not os.path.exists(os.path.join(filesystem.user_data(), "learningtrees")):
-                os.makedirs(os.path.join(filesystem.user_data(), "learningtrees"))
+                os.mkdir(os.path.join(filesystem.user_data(), "learningtrees"))
             for fn in os.listdir(os.path.join(filesystem.app_data(), "learningtrees")):
                 if not os.path.exists(os.path.join(filesystem.user_data(), "learningtrees", fn)):
                     shutil.move(os.path.join(filesystem.app_data(), "learningtrees", fn),
@@ -869,6 +857,8 @@ cfg.set_bool('config/no_random', bool(options.no_random))
 if splash_win:
     splash_win.show_progress("creating LessonfileManager")
 lessonfile_manager = lessonfile.LessonFileManager(options.debug)
+lessonfile.manager = lessonfile_manager
+statistics.db = statistics.DB()
 
 if splash_win:
     splash_win.hide()
