@@ -20,7 +20,7 @@ import lessonfilegui
 
 
 class MatrixTable(gtk.VBox):
-    def __init__(self, heading, keys, key_to_pretty_name, dict):
+    def __init__(self, heading, st, seconds):
         gtk.VBox.__init__(self)
         label = gtk.Label(heading)
         label.set_name("StatisticsH2")
@@ -31,19 +31,21 @@ class MatrixTable(gtk.VBox):
         hbox.pack_start(frame, False)
         t = gtk.Table()
         frame.add(t)
+        st_data = st.get_statistics(0)
+        keys = st.get_keys(True)
         for x in range(len(keys)):
             t.attach(gtk.VSeparator(), x*2+1, x*2+2, 0, len(keys)*2)
         for x in range(len(keys)-1):
             t.attach(gtk.HSeparator(), 0, len(keys)*2+1, x*2+1, x*2+2)
         for y in range(len(keys)):
-            l = lessonfilegui.new_labelobject(key_to_pretty_name(keys[y]))
+            l = lessonfilegui.new_labelobject(st.key_to_pretty_name(keys[y]))
             l.set_alignment(0.0, 0.5)
             t.attach(l, 0, 1, y*2, y*2+1, xpadding=gu.PAD)
             for x in range(len(keys)):
-                if keys[x] in dict and keys[y] in dict[keys[x]]:
-                    s = str(dict[keys[x]][keys[y]])
-                else:
-                    s = "0"
+                try:
+                    s = st_data[keys[x]][keys[y]]
+                except KeyError:
+                    s = '-'
                 l = gtk.Label(s)
                 if x == y:
                     l.set_name('BoldText')
@@ -87,21 +89,27 @@ class PercentagesTable(gtk.Frame):
             for o in box.get_children():
                 o.destroy()
         for k in statistics.get_keys():
+            # FIXME  Has this bug been fixed? This should NEVER happen.
+            if k is None:
+                print "WARNING: statistics: key==None. Please, please report to"
+                print "bug-solfege@gnu.org if you get this message. Preferably,"
+                print "make a copy ~/.solfege so I can debug this."
             l = lessonfilegui.new_labelobject(statistics.key_to_pretty_name(k))
             l.set_alignment(0.0, 0.5)
             self.boxdict['keys'].pack_start(l)
-            for sk, st in (('session', statistics.m_session_stat),
-                       ('today', statistics.m_today_stat),
-                       ('last7', statistics.m_last7_stat),
-                       ('total', statistics.m_total_stat)):
+            for sk, seconds in (('session', 0),
+                       ('today', 60*60*24),
+                       ('last7', 60*60*24*7),
+                       ('total', -1)):
 
-                if statistics.get_percentage_correct(st, k) == 0.0:
+                percentage = statistics.get_percentage_correct_for_key(seconds, k)
+                if percentage == 0.0:
                     self.boxdict[sk+'percent'].pack_start(gtk.Label("-"))
                 else:
                     self.boxdict[sk+'percent'].pack_start(
-                        gtk.Label("%.0f" % statistics.get_percentage_correct(st, k)))
+                        gtk.Label("%.0f" % percentage))
                 self.boxdict[sk+'count'].pack_start(
-                    gtk.Label(str(statistics.get_num_guess(st, k))))
+                    gtk.Label(str(statistics.get_num_guess_for_key(seconds, k))))
         self.show_all()
 
 class NewAbstractStatisticsViewer(gtk.ScrolledWindow):
@@ -164,24 +172,20 @@ class StatisticsViewer(NewAbstractStatisticsViewer):
         self.g_tables.pack_start(self.g_p, False)
         self.matrix_dict['session'] = MatrixTable(
                                            _("Session"),
-                                           self.m_statistics.get_keys(1),
-                                           self.m_statistics.key_to_pretty_name,
-                                           self.m_statistics.m_session_stat)
+                                           self.m_statistics,
+                                           0)
         self.matrix_dict['today'] = MatrixTable(
                                            _("Today"),
-                                           self.m_statistics.get_keys(1),
-                                           self.m_statistics.key_to_pretty_name,
-                                           self.m_statistics.m_today_stat)
+                                           self.m_statistics,
+                                           60*60*24)
         self.matrix_dict['last7'] = MatrixTable(
                                            _("Last 7 days"),
-                                           self.m_statistics.get_keys(1),
-                                           self.m_statistics.key_to_pretty_name,
-                                           self.m_statistics.m_last7_stat)
+                                           self.m_statistics,
+                                           60*60*24*7)
         self.matrix_dict['total'] = MatrixTable(
                                            _("Total"),
-                                           self.m_statistics.get_keys(1),
-                                           self.m_statistics.key_to_pretty_name,
-                                           self.m_statistics.m_total_stat)
+                                           self.m_statistics,
+                                           -1)
 
         for k in ('session', 'today', 'last7', 'total'):
             self.g_tables.pack_start(self.matrix_dict[k], False)
