@@ -8,6 +8,9 @@ import unittest
 import os
 import src
 
+import __builtin__
+__builtin__.testsuite_is_running = True
+
 outdir = 'test-outdir'
 
 class I18nSetup(unittest.TestCase):
