@@ -1,13 +1,16 @@
-#!/usr/bin/python2.3
+#!/usr/bin/python
 import sys
 sys.path.insert(0, ".")
+import src.i18n
+src.i18n.setup(".", "C")
+import src.cfg
+import src.filesystem
+src.cfg.initialise("default.config", None, src.filesystem.rcfile())
 import soundcard
 
 ## This works nice with ALSA and OSS emulation with SB Live card:
-import src.i18n
-src.i18n.setup(".")
-soundcard.initialise_external_midiplayer("/usr/bin/timidity", False)
-#soundcard.initialise_devicefile("/dev/sequencer2", 2)
+#soundcard.initialise_external_midiplayer("/usr/bin/timidity", False)
+soundcard.initialise_devicefile("/dev/sequencer2", 2)
 
 
 print """
